@@ -121,6 +121,14 @@ impl Params {
     /// Key identifier: byte slice between 0 and 8 bytes in length.
     ///
     /// Defaults to an empty byte slice.
+    ///
+    /// Note this field is only present as a helper for reading/storing in
+    /// the PHC hash string format (i.e. it is totally ignored from a
+    /// cryptographical standpoint).
+    ///
+    /// On top of that, this field is not longer part of the argon2 standard
+    /// (see: https://github.com/P-H-C/phc-winner-argon2/pull/173), and should
+    /// not be used for any non-legacy work.
     pub fn keyid(&self) -> &[u8] {
         self.keyid.as_bytes()
     }
@@ -128,6 +136,10 @@ impl Params {
     /// Associated data: byte slice between 0 and 32 bytes in length.
     ///
     /// Defaults to an empty byte slice.
+    ///
+    /// This field is not longer part of the argon2 standard
+    /// (see: https://github.com/P-H-C/phc-winner-argon2/pull/173), and should
+    /// not be used for any non-legacy work.
     pub fn data(&self) -> &[u8] {
         self.data.as_bytes()
     }
@@ -288,10 +300,10 @@ impl<'a> TryFrom<&'a PasswordHash<'a>> for Params {
                     builder.p_cost(value.decimal()?)?;
                 }
                 "keyid" => {
-                    builder.params.keyid = ident.as_str().parse()?;
+                    builder.params.keyid = value.as_str().parse()?;
                 }
                 "data" => {
-                    builder.params.data = ident.as_str().parse()?;
+                    builder.params.data = value.as_str().parse()?;
                 }
                 _ => return Err(password_hash::Error::ParamNameInvalid),
             }
@@ -445,3 +457,49 @@ impl TryFrom<ParamsBuilder> for Params {
         builder.params()
     }
 }
+
+#[cfg(all(test, feature = "alloc", feature = "password-hash"))]
+mod tests {
+
+    use super::*;
+
+    #[test]
+    fn params_builder_bad_values() {
+        let mut builder = ParamsBuilder::new();
+
+        assert_eq!(
+            builder.m_cost(Params::MIN_M_COST - 1),
+            Err(Error::MemoryTooLittle)
+        );
+        assert_eq!(
+            builder.m_cost(Params::MAX_M_COST + 1),
+            Err(Error::MemoryTooMuch)
+        );
+        assert_eq!(
+            builder.t_cost(Params::MIN_T_COST - 1),
+            Err(Error::TimeTooSmall)
+        );
+        assert_eq!(
+            builder.p_cost(Params::MIN_P_COST - 1),
+            Err(Error::ThreadsTooFew)
+        );
+        assert_eq!(
+            builder.p_cost(Params::MAX_P_COST + 1),
+            Err(Error::ThreadsTooMany)
+        );
+    }
+
+    #[test]
+    fn params_builder_data_too_long() {
+        let mut builder = ParamsBuilder::new();
+        let ret = builder.data(&[0u8; Params::MAX_DATA_LEN + 1]);
+        assert_eq!(ret, Err(Error::AdTooLong));
+    }
+
+    #[test]
+    fn params_builder_keyid_too_long() {
+        let mut builder = ParamsBuilder::new();
+        let ret = builder.keyid(&[0u8; Params::MAX_KEYID_LEN + 1]);
+        assert_eq!(ret, Err(Error::KeyIdTooLong));
+    }
+}
